@@ -15,20 +15,23 @@ check_reml = function(reml, model)
 
 check_conv = function(repml, conv, nb, vare, min, max, cutoff = 1e-8)
 {
-  if(vare[1]==max[1] | vare[2]==min[2])
+  if(conv==1)
   {
-    conv = -60
-  }else{
-    if(is.nan(repml$loglik))
-    {conv = -30}else{
-      if(repml$iter==50)
-      {
-        conv = -20
-      }else{
-        if(repml$damp==11)
-        {conv = -10}else{
-          if(repml$damp==12)
-          {conv = -40}
+    if(vare[1]==max[1] | vare[2]==min[2])
+    {
+      conv = -60
+    }else{
+      if(is.nan(repml$loglik))
+      {conv = -30}else{
+        if(repml$iter==50)
+        {
+          conv = -20
+        }else{
+          if(repml$damp==11)
+          {conv = -10}else{
+            if(repml$damp==12)
+            {conv = -40}
+          }
         }
       }
     }
